getifaddrs

Function getifaddrs 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn getifaddrs(ifap: *mut *mut ifaddrs) -> c_int
Creates a linked list of structures describing the network interfaces of the local system, and stores the address of the first item of the list in ifap.

The data returned by getifaddrs() is dynamically allocated and should be freed using freeifaddrs() when no longer needed.